==> io-8.x-1.2.tar.gz: io/js/io.block.js <==
/**
 * @file
 * Provides Intersection Observer for ajaxified blocks.
 */

(function (Drupal, drupalSettings, _db, window) {

  'use strict';

  Drupal.blazy = Drupal.blazy || {};

  /**
   * Intersection Observer API public methods for Drupal blocks.
   *
   * @namespace
   */
  Drupal.io.block = _db.extend({}, Drupal.io.base, {
    settings: drupalSettings.io.block || {},
    $trigger: '[data-io-block-trigger]',
    dataHit: 'data-io-block-hit',
    dataLoaded: 'data-io-block-loaded',
    dataTrigger: 'data-io-block-trigger',
    globals: function () {
      var me = this;
      var commons = {
        intersecting: me.intersecting.bind(me),
        success: me.success.bind(me),
        error: me.error.bind(me)
      };

      return _db.extend({}, me.settings, commons);
    },

    ajaxSettings: function (el) {
      var uuid = el.hasAttribute(this.dataTrigger);

      return !uuid ? false : {
        url: el.href,
        element: el,
        event: 'click touchstart',
        io: 'block'
      };
    },

    ajax: function (el, resolve, reject) {
      var me = this;
      var _settings = me.ajaxSettings(el);

      if (!_settings) {
        return false;
      }

      // @todo check out Native fetch(), if no issues with assets loading.
      var ajax = new Drupal.Ajax(null, null, _settings);
      var _ajaxOptions = ajax.options;
      var _complete = _ajaxOptions.complete;

      // Do not override Drupal.Ajax.prototype.error|success to avoid multiple
      // invocations on unrelated AJAX requests. Instead overrides its options.
      _ajaxOptions.complete = function complete(xmlhttprequest, status) {
        // Ensures our own AJAX, not anyone's else.
        if (ajax.elementSettings && 'io' in ajax.elementSettings) {
          // Prevents dead errors without resolutions.
          if (status === 'error' || status === 'parsererror') {
            return reject();
          }
          else {
            // Drupal.Ajax.options.success is not always called, assumed so.
            resolve();
          }
        }

        // Makes the _super run last to catch validations.
        _complete.apply(this, arguments);
      };

      return ajax;
    },

    promise: function (el) {
      var me = this;
      return new Promise(function (resolve, reject) {

        // Bail out if AJAX is already hit, or unless an error is spit out.
        if (me.isError(el) || !el.hasAttribute(me.dataHit)) {
          var ajax = me.ajax(el, resolve, reject);
          if (ajax) {
            // Executes the Drupal.Ajax instance.
            ajax.execute();
            el.setAttribute(me.dataHit, 0);
          }
        }
      });
    },

    intersecting: function (el) {
      var me = this;
      var parent = el.parentNode;

      // If hit (0), or success (1), and not error (-1), bail out.
      if (el.hasAttribute(me.dataHit) && !me.isError(el)) {
        return;
      }

      return me.promise(el)
        .then(function () {
          me.success(el, 1, parent);
        })
        .catch(function () {
          me.error(el, -1, parent);
        });
    }
  });

  /**
   * Auto load ajaxified blocks using the Intersection Observer.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.ioBlock = {
    attach: function () {
      var me = Drupal.io.block;

      // Initializes Ajaxin instance, if available.
      me.ajaxin = me.initAjaxin(me.settings);

      // Initializes Io instance.
      me.init = me.run(me.globals());

      // Ensures fallback is provied if anything fails.
      var doClick = function (e) {
        var el = e.target.classList.contains('io__text') ? e.target.parentNode : e.target;
        e.preventDefault();

        me.reIntersecting(el);
      };

      _db.on(document.body, 'click', me.$trigger, doClick);
    }
  };

})(Drupal, drupalSettings, dBlazy, this);

==> io-8.x-1.3.tar.gz: io/js/io.block.js <==
/**
 * @file
 * Provides Intersection Observer for ajaxified blocks.
 */

(function (Drupal, drupalSettings, once, _db, window) {

  'use strict';

  var _id = 'io-block';
  var _element = 'html';

  Drupal.blazy = Drupal.blazy || {};

  /**
   * Intersection Observer API public methods for Drupal blocks.
   *
   * @namespace
   */
  Drupal.io.block = _db.extend({}, Drupal.io.base, {
    settings: drupalSettings.io.block || {},
    $trigger: '[data-' + _id + '-trigger]',
    dataHit: 'data-' + _id + '-hit',
    dataLoaded: 'data-' + _id + '-loaded',
    dataTrigger: 'data-' + _id + '-trigger',
    globals: function () {
      var me = this;
      var commons = {
        intersecting: me.intersecting.bind(me),
        success: me.success.bind(me),
        error: me.error.bind(me)
      };

      return _db.extend({}, me.settings, commons);
    },

    ajaxSettings: function (el) {
      var uuid = el.hasAttribute(this.dataTrigger);

      return !uuid ? false : {
        url: el.href,
        element: el,
        event: 'click touchstart',
        io: 'block'
      };
    },

    ajax: function (el, resolve, reject) {
      var me = this;
      var _settings = me.ajaxSettings(el);

      if (!_settings) {
        return false;
      }

      // @todo check out Native fetch(), if no issues with assets loading.
      var ajax = new Drupal.Ajax(null, null, _settings);
      var _ajaxOptions = ajax.options;
      var _complete = _ajaxOptions.complete;

      // Do not override Drupal.Ajax.prototype.error|success to avoid multiple
      // invocations on unrelated AJAX requests. Instead overrides its options.
      _ajaxOptions.complete = function complete(xmlhttprequest, status) {
        // Ensures our own AJAX, not anyone's else.
        if (ajax.elementSettings && 'io' in ajax.elementSettings) {
          // Prevents dead errors without resolutions.
          if (status === 'error' || status === 'parsererror') {
            return reject();
          }
          else {
            // Drupal.Ajax.options.success is not always called, assumed so.
            resolve();
          }
        }

        // Makes the _super run last to catch validations.
        _complete.apply(this, arguments);
      };

      return ajax;
    },

    promise: function (el) {
      var me = this;
      return new Promise(function (resolve, reject) {

        // Bail out if AJAX is already hit, or unless an error is spit out.
        if (me.isError(el) || !el.hasAttribute(me.dataHit)) {
          var ajax = me.ajax(el, resolve, reject);
          if (ajax) {
            // Executes the Drupal.Ajax instance.
            ajax.execute();
            el.setAttribute(me.dataHit, 0);
          }
        }
      });
    },

    intersecting: function (el) {
      var me = this;
      var parent = el.parentNode;

      // If hit (0), or success (1), and not error (-1), bail out.
      if (el.hasAttribute(me.dataHit) && !me.isError(el)) {
        return;
      }

      return me.promise(el)
        .then(function () {
          me.success(el, 1, parent);
        })
        .catch(function () {
          me.error(el, -1, parent);
        });
    }
  });

  /**
   * IO block utility functions.
   *
   * @param {HTMLElement} elm
   *   The document HTML element.
   */
  function doBlock(elm) {
    var me = Drupal.io.block;

    // Initializes Ajaxin instance, if available.
    me.ajaxin = me.initAjaxin(me.settings);

    // Initializes Io instance.
    me.init = me.run(me.globals());

    // Ensures fallback is provied if anything fails.
    var doClick = function (e) {
      var el = e.target.classList.contains('io__text') ? e.target.parentNode : e.target;
      e.preventDefault();

      me.reIntersecting(el);
    };

    _db.on(elm, 'click', me.$trigger, doClick);
  }

  /**
   * Auto load ajaxified blocks using the Intersection Observer.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.ioBlock = {
    attach: function (context) {

      context = Drupal.io.block.context(context);

      once(_id, _element, context).forEach(doBlock);
    },
    detach: function (context, setting, trigger) {
      if (trigger === 'unload') {
        if (once.find(_id, context).length) {
          once.remove(_id, _element, context);
        }
      }
    }
  };

})(Drupal, drupalSettings, once, dBlazy, this);
